@@ -1,21 +1,24 @@
-__version__ = '0.0.40'  # print(ultralytics.__version__)
+__version__ = '0.0.41'  # print(ultralytics.__version__)
 
 
 def checks(verbose=True):
-    # Checks YOLOv5 software and hardware
+    # Check system software and hardware
     print('Checking setup...')
 
     import os
     import shutil
-    from .utils.general import emojis, check_requirements
+    from .utils.general import check_requirements, emojis, is_colab
     from .utils.torch_utils import select_device  # imports
 
-    if verbose:
-        check_requirements(('psutil', 'IPython'))
-        import psutil
-        from IPython import display  # to display images and clear console output
+    check_requirements(('psutil', 'IPython'))
+    import psutil
+    from IPython import display  # to display images and clear console output
 
-        # System
+    if is_colab():
+        shutil.rmtree('sample_data', ignore_errors=True)  # remove colab /sample_data directory
+
+    if verbose:
+        # System info
         # gb = 1 / 1000 ** 3  # bytes to GB
         gib = 1 / 1024 ** 3  # bytes to GiB
         ram = psutil.virtual_memory().total
